@@ -1,16 +1,27 @@
 ## ---- message=FALSE------------------------------------------------------
 library(networkreporting)
-library(plyr)
-library(ggplot2) # we'll use qplot from ggplot2 for plots
-theme_set(theme_minimal())
+library(surveybootstrap)
+
+## column names for connections to hidden population numbers
+hidden.q <- c("sex.workers", "msm", "idu", "clients")
+
+## column names for connections to groups of known size
+hm.q <- c("widower", "nurse.or.doctor", "male.community.health", "teacher", 
+          "woman.smoke", "priest", "civil.servant", "woman.gave.birth", 
+          "muslim", "incarcerated", "judge", "man.divorced", "treatedfortb", 
+          "nsengimana", "murekatete", "twahirwa", "mukandekezi", "nsabimana", 
+          "mukamana", "ndayambaje", "nyiraneza", "bizimana", "nyirahabimana", 
+          "ndagijimana", "mukandayisenga", "died")
+
+## size of the entire population
+tot.pop.size <- 10718378
 
-data(hhsurvey) # this is a demo dataset included with the package
 
 ## ------------------------------------------------------------------------
-knownpop.dat
+example.knownpop.dat
 
 ## ------------------------------------------------------------------------
-kp.vec <- df.to.kpvec(knownpop.dat, kp.var="known.popn", kp.value="size")
+kp.vec <- df.to.kpvec(example.knownpop.dat, kp.var="known.popn", kp.value="size")
 
 kp.vec
 
@@ -24,7 +35,7 @@ head(example.survey)
 ## ------------------------------------------------------------------------
 ## make a vector with the list of known population names from
 ## our dataset of known population totals
-known.popn.vars <- paste(knownpop.dat$known.popn)
+known.popn.vars <- paste(example.knownpop.dat$known.popn)
 
 ## before topcoding: max. response for several popns is > 30
 summary(example.survey[,known.popn.vars])
@@ -45,30 +56,16 @@ d.hat <- kp.degree.estimator(survey.data=example.survey,
 
 summary(d.hat)
 
+## ---- message=FALSE------------------------------------------------------
+library(ggplot2) # we'll use qplot from ggplot2 for plots
+theme_set(theme_minimal())
+
 ## ------------------------------------------------------------------------
 qplot(d.hat, binwidth=25)
 
 ## ------------------------------------------------------------------------
 example.survey$d.hat <- d.hat
 
-## ---- tidy=FALSE---------------------------------------------------------
-iv.result <- nsum.internal.validation(survey.data=example.survey,
-                                      known.popns=kp.vec,
-                                      missing="complete.obs",
-                                      killworth.se=TRUE,
-                                      total.popn.size=tot.pop.size,
-                                      kp.method=TRUE,
-                                      return.plot=TRUE)
-
-## ------------------------------------------------------------------------
-iv.result$results
-
-## ------------------------------------------------------------------------
-print(iv.result$plot)
-
-## ------------------------------------------------------------------------
-print(iv.result$plot + ggtitle("internal validation checks"))
-
 ## ---- tidy=FALSE---------------------------------------------------------
 idu.est <- nsum.estimator(survey.data=example.survey,
                           d.hat.vals=d.hat,
@@ -108,6 +105,7 @@ idu.est <- bootstrap.estimates(## this describes the sampling design of the
                                missing="complete.obs")
 
 ## ------------------------------------------------------------------------
+library(plyr)
 ## combine the estimates together in one data frame
 ## (bootstrap.estimates gives us a list)
 all.idu.estimates <- ldply(idu.est,
@@ -120,6 +118,27 @@ qplot(all.idu.estimates$estimate, binwidth=50)
 ## summarize the results
 summary(all.idu.estimates$estimate)
 
+## ------------------------------------------------------------------------
+quantile(all.idu.estimates$estimate, probs=c(0.025, 0.975))
+
+## ---- tidy=FALSE---------------------------------------------------------
+iv.result <- nsum.internal.validation(survey.data=example.survey,
+                                      known.popns=kp.vec,
+                                      missing="complete.obs",
+                                      killworth.se=TRUE,
+                                      total.popn.size=tot.pop.size,
+                                      kp.method=TRUE,
+                                      return.plot=TRUE)
+
+## ------------------------------------------------------------------------
+iv.result$results
+
+## ------------------------------------------------------------------------
+print(iv.result$plot)
+
+## ------------------------------------------------------------------------
+print(iv.result$plot + ggtitle("internal validation checks"))
+
 ## ------------------------------------------------------------------------
 example.survey <- add.kp(example.survey, kp.vec, tot.pop.size)
 
